@@ -11,6 +11,7 @@ from datapac.rcave.services.push import push as push_service
 from datapac.rcave.sources.postgres.source import load_artefacts as pg_load_artefacts
 from datapac.rcave.sources.s3.source import load_artefacts as s3_load_artefacts
 from datapac.rcave.utils.query import Query
+from datapac.rcave.utils.query import infer_variables
 from datapac.rcave.utils.query import load as load_query
 
 config: Config | None
@@ -42,6 +43,12 @@ def validate_config(ctx, param, value) -> Config:
     return load_config(value)
 
 
+def resolve_variables_for_pull(variables: dict, query: Query):
+    missing = infer_variables(query) - set(variables.keys())
+    prompts = {var: click.prompt(f"Enter {var}", type=str) for var in missing}
+    return variables | prompts
+
+
 @click.group()
 @click.option(
     "c",
@@ -74,7 +81,7 @@ def cli(c):
     callback=validate_env,
 )
 @click.option(
-    "--vars",
+    "--variable",
     "-v",
     "variables",
     type=(str, str),
@@ -87,8 +94,13 @@ def cli(c):
     callback=validate_path,
 )
 def pull(query: Query, env: Environment, variables: dict, path: str):
+    resolved_variables = resolve_variables_for_pull(
+        env.variables | variables,
+        query=query,
+    )
+
     with package.create(path) as pkg:
-        pull_service(env, query, (env.variables or {}) | variables, pkg)
+        pull_service(env, query, resolved_variables, pkg)
 
 
 @cli.command()
@@ -101,7 +113,7 @@ def pull(query: Query, env: Environment, variables: dict, path: str):
     callback=validate_env,
 )
 @click.option(
-    "--vars",
+    "--variable",
     "-v",
     "variables",
     type=(str, str),
@@ -115,7 +127,8 @@ def pull(query: Query, env: Environment, variables: dict, path: str):
 )
 def push(env: Environment, variables: dict, path: str):
     with package.open(path, [pg_load_artefacts, s3_load_artefacts]) as pkg:
-        push_service(env, pkg, (env.variables or {}) | variables)
+        with package.render(pkg, env.variables | variables) as rendered:
+            push_service(env, rendered)
 
 
 if __name__ == "__main__":
