@@ -1,19 +1,20 @@
+from datapac.config import Environment
 from datapac.package.package import Package
 from datapac.rcave.sources.postgres import source as postgres
 from datapac.rcave.sources.s3 import source as s3
-from datapac.rcave.utils.graph import Graph
-from datapac.rcave.utils.graph import PostgresNode
-from datapac.rcave.utils.graph import S3Node
-from datapac.utils.environment import Environment
+from datapac.rcave.utils.query import Graph
+from datapac.rcave.utils.query import PostgresNode
+from datapac.rcave.utils.query import Query
+from datapac.rcave.utils.query import S3Node
 
 
 def pull(
     env: Environment,
-    graph: Graph,
+    query: Query,
     variables: dict,
     pkg: Package,
 ):
-    for artefact in crawl(env, graph, variables):
+    for artefact in crawl(env, query.graph, variables):
         pkg.add_artefact(artefact)
 
 
