@@ -82,10 +82,3 @@ def pull_node(env: Environment, node: S3Node, variables: dict):
         client.download(conn, bucket, key, abs_path)
 
     return artefact
-
-
-def push_artefacts(env: Environment, artefacts: list[S3Artefact]):
-    with client.connect(env.sources.s3) as conn:
-        for artefact in artefacts:
-            print(f"[source:s3] pushing {artefact} artefact")
-            client.upload(conn, artefact.bucket, artefact.key, artefact.tmp_path)
