@@ -6,6 +6,8 @@ from pydantic import BaseModel
 from pydantic import Field
 from typing_extensions import Annotated
 
+from datapac.utils import templating
+
 Graph = Annotated[Union["S3Node", "PostgresNode"], Field(discriminator="type")]
 
 
@@ -26,16 +28,18 @@ class PostgresNode(BaseModel):
 
 
 class Query(BaseModel):
+    path: str
     graph: Graph
 
     class Config:
         orm_mode = True
 
 
-def load_yaml(input) -> Query:
-    return Query(**yaml.safe_load(input))
+def infer_variables(query: Query):
+    with open(query.path) as f:
+        return templating.infer_variables(f.read()) - {"parent"}
 
 
 def load(path: str) -> Query:
     with open(path) as f:
-        return load_yaml(f)
+        return Query(path=path, **yaml.safe_load(f.read()))
